<?php
/**
 * The control file for purchasecontract of ZDOO.
 *
 * @copyright   Copyright 2009-2018 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL (http://zpl.pub/page/zplv12.html)
 * @author      Dongdong Jia <jiadongdong@easycorp.ltd>
 * @package     purchasecontract
 * @version     $Id$
 * @link        http://www.zdoo.com
 */
class purchasecontract extends control
{
    /**
     * Contract index page.
     *
     * @access public
     * @return void
     */
    public function index()
    {
        $this->locate(inlink('browse'));
    }

    /**
     * Browse all purchase contracts;
     *
     * @param  string $mode
     * @param  string $orderBy
     * @param  int    $recTotal
     * @param  int    $recPerPage
     * @param  int    $pageID
     * @access public
     * @return void
     */
    public function browse($mode = 'all', $orderBy = 'id_desc', $recTotal = 0, $recPerPage = 20, $pageID = 1)
    {
        $this->app->loadClass('pager', $static = true);
        $pager = new pager($recTotal, $recPerPage, $pageID);

        $contracts  = $this->loadModel('contract')->getList('purchase', 0, $mode, '', $orderBy, $pager);

        /* Save session for return link. */
        $this->session->set('purchasecontractList', $this->app->getURI(true));

        /* Build search form. */
        $this->loadModel('search');
        $this->config->purchasecontract->search['actionURL'] = inlink('browse', "mode=bysearch");
        $this->config->purchasecontract->search['params']['product']['values']  = array('' => '') + $this->loadModel('product')->getPairs();
        $this->search->setSearchParams($this->config->purchasecontract->search);

        /* Set allowed edit contract ID list. */
        $this->app->user->canEditContractIdList = ',' . implode(',', $this->contract->getContractsSawByMe('edit', array_keys($contracts))) . ',';

        $this->view->moduleMenu   = $this->contract->createModuleMenu('purchasecontract', 'purchase');
        $this->view->title        = $this->lang->purchasecontract->browse;
        $this->view->contracts    = $contracts;
        $this->view->customers    = $this->loadModel('customer')->getPairs('provider');
        $this->view->currencySign = $this->loadModel('common')->getCurrencySign();
        $this->view->currencyList = $this->common->getCurrencyList();
        $this->view->type         = 'purchase';
        $this->view->moduleType   = 'purchasecontract';
        $this->view->mode         = $mode;
        $this->view->orderBy      = $orderBy;
        $this->view->pager        = $pager;
        if($contracts) $this->view->totalAmount = $this->contract->countAmount($contracts);

        $this->display('contract', 'browse');
    }

    /**
     * Create contract.
     *
     * @param  int    $customerID
     * @param  int    $orderID
     * @access public
     * @return void
     */
    public function create($type = 'purchase', $customerID = 0, $orderID = 0)
    {
        die($this->fetch('contract', 'create', "type=purchase&customerID={$customerID}&orderID={$orderID}", 'crm'));
    }

    /**
     * Edit contract.
     *
     * @param  int    $contractID
     * @param  bool   $comment
     * @access public
     * @return void
     */
    public function edit($contractID, $comment = false)
    {
        die($this->fetch('contract', 'edit', "contractID={$contractID}&comment={$comment}", 'crm'));
    }

    /**
     * Pay the contract.
     *
     * @param  int    $contractID
     * @access public
     * @return void
     */
    public function pay($contractID)
    {
        die($this->fetch('contract', 'receive', "contractID={$contractID}", 'crm'));
    }

    /**
     * Edit return.
     *
     * @param  int    $returnID
     * @access public
     * @return void
     */
    public function editReturn($returnID)
    {
        die($this->fetch('contract', 'editReturn', "returnID={$returnID}", 'crm'));
    }

    /**
     * Delete return.
     *
     * @param  int    $returnID
     * @access public
     * @return void
     */
    public function deleteReturn($returnID)
    {
        die($this->fetch('contract', 'deleteReturn', "returnID={$returnID}", 'crm'));
    }

    /**
     * Cancel contract.
     *
     * @param  int    $contractID
     * @access public
     * @return void
     */
    public function cancel($contractID)
    {
        die($this->fetch('contract', 'cancel', "contractID={$contractID}", 'crm'));
    }

    /**
     * Finish contract.
     *
     * @param  int    $contractID
     * @access public
     * @return void
     */
    public function finish($contractID)
    {
        die($this->fetch('contract', 'finish', "contractID={$contractID}", 'crm'));
    }

    /**
     * View contract.
     *
     * @param  int    $contractID
     * @access public
     * @return void
     */
    public function view($contractID)
    {
        die($this->fetch('contract', 'view', "contractID={$contractID}", 'crm'));
    }

    /**
     * Delete contract.
     *
     * @param  int    $contractID
     * @access public
     * @return void
     */
    public function delete($contractID)
    {
        $this->dao->update(TABLE_CONTRACT)->set('deleted')->eq(1)->where('id')->eq($contractID)->exec();
        if(dao::isError()) $this->send(array('result' => 'fail', 'message' => dao::getError()));

        $this->loadModel('action')->create('purchasecontract', $contractID, 'deleted', '', $extra = ACTIONMODEL::CAN_UNDELETED);

        $this->send(array('result' => 'success', 'locate' => inlink('browse')));
    }

    /**
     * Export contracts.
     *
     * @param  string $type     purchase
     * @param  string $mode     all | thisPage
     * @access public
     * @return void
     */
    public function export($type = 'purchase', $mode = 'all')
    {
        die($this->fetch('contract', 'export', "type=purchase&mode={$mode}", 'crm'));
    }
}
